Author: bugman
Date: Fri Nov 23 16:38:19 2007
New Revision: 3862

URL: http://svn.gna.org/viewcvs/relax?rev=3862&view=rev
Log:
Updated the docstring of the write() function.


Modified:
    1.3/generic_fns/sequence.py

Modified: 1.3/generic_fns/sequence.py
URL: 
http://svn.gna.org/viewcvs/relax/1.3/generic_fns/sequence.py?rev=3862&r1=3861&r2=3862&view=diff
==============================================================================
--- 1.3/generic_fns/sequence.py (original)
+++ 1.3/generic_fns/sequence.py Fri Nov 23 16:38:19 2007
@@ -273,7 +273,28 @@
 
 
 def write(file=None, dir=None, mol_name_col=None, res_num_col=None, 
res_name_col=None, spin_num_col=None, spin_name_col=None, sep=None, force=0):
-    """Function for writing sequence data."""
+    """Function for writing molecule, residue, and/or sequence data.
+
+    @param file:            The name of the file to write the data to.
+    @type file:             str
+    @param dir:             The directory to contain the file (defaults to the 
current directory if
+                            None).
+    @type dir:              str or None
+    @param mol_name_col:    The column to contain the molecule name 
information.
+    @type mol_name_col:     int or None
+    @param res_name_col:    The column to contain the residue name information.
+    @type res_name_col:     int or None
+    @param res_num_col:     The column to contain the residue number 
information.
+    @type res_num_col:      int or None
+    @param spin_name_col:   The column to contain the spin name information.
+    @type spin_name_col:    int or None
+    @param spin_num_col:    The column to contain the spin number information.
+    @type spin_num_col:     int or None
+    @param sep:             The column seperator which, if None, defaults to 
whitespace.
+    @type sep:              str or None
+    @param force:           A flag which if set to 1 will cause an existing 
file to be overwritten.
+    @type force:            bin
+    """
 
     # Test if the sequence data is loaded.
     if not count_spins():


_______________________________________________
relax (http://nmr-relax.com)

This is the relax-commits mailing list
relax-commits@gna.org

To unsubscribe from this list, get a password
reminder, or change your subscription options,
visit the list information page at
https://mail.gna.org/listinfo/relax-commits

Reply via email to